﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Data;
using System.Configuration;
using System.Data.SqlClient;
using System.Text;

using ServiceReference;
using System.Net;

/// <summary>
/// Summary description for MyEventHelper
/// </summary>
public static class MyEventHelper
{
    #region "Event methods"

    public static DataSet GetAllEvents(string columns)
    {
        return ExecuteQuery("Select " + columns + " FROM Event");
    }

    public static DataSet GetEventUser(int eventUserId)
    {
        if (eventUserId > 0)
        {
            return ExecuteQuery(string.Format("Select * FROM EventUser WHERE EventUserID = '{0}'", eventUserId));
        }
        else
        {
            return null;
        }
    }

    public static bool UpdateEventUser(int eventUserId, string userName, string email, int eventUserEventID)
    {
        if (eventUserId > 0)
        {
            string queryText = string.Format("UPDATE EventUser SET EventUserName = '{0}', EventUserEmail = '{1}', EventUserEventID = '{2}' WHERE EventUserID = {3}", userName, email, eventUserEventID, eventUserId);

            return (ExecuteNonQuery(queryText) > 0);
        }
        else
        {
            return false;
        }
    }

    public static int CreateEventUser(string userName, string email, int eventUserEventId)
    {
        string queryText = string.Format("INSERT INTO EventUser (EventUserName, EventUserEmail, EventUserEventID, EventUserGUID) VALUES ('{0}','{1}','{2}', '{3}') SET @ID =  SCOPE_IDENTITY()",
            userName, email, eventUserEventId, Guid.NewGuid());

        return ExecuteNonQuery(queryText, true);
    }

    public static bool DeleteEventUser(int eventUserId)
    {
        bool result = false;

        if (eventUserId > 0)
        {
            string queryText = string.Format("DELETE FROM EventUser WHERE EventUserID = '{0}'", eventUserId);

            if (ExecuteNonQuery(queryText) > 0)
            {
                return true;
            }
        }

        return result;
    }

    #endregion

    #region "Data manipulation methods"

    public static string GetConnectionString(string connectionStringName)
    {
        ConnectionStringSettingsCollection settings = ConfigurationManager.ConnectionStrings;

        if (settings != null)
        {
            foreach (ConnectionStringSettings cs in settings)
            {
                if (cs.Name.ToLower() == connectionStringName.ToLower())
                {
                    return cs.ConnectionString;
                }
            }
        }

        return "";
    }
    
    public static int ExecuteNonQuery(string queryText, bool returnInsertedId)
    {
        int result = 0;
        
        if (!string.IsNullOrEmpty(queryText))
        {
            using (var connection = new SqlConnection(GetConnectionString("MyExternalConnectionString")))
            {
                try
                {
                   SqlCommand command = new SqlCommand(queryText, connection);

                   if (returnInsertedId)
                   {
                       SqlParameter outParameter = new SqlParameter("@ID", SqlDbType.Int);
                       outParameter.Direction = ParameterDirection.Output;
                       command.Parameters.Add(outParameter);
                   }
                    
                   command.Connection.Open();
      
                   if ((result = command.ExecuteNonQuery()) > 0)
                    {
                        if (returnInsertedId)
                        {
                            result = Convert.ToInt32(command.Parameters["@ID"].Value);
                        }
                    }
                }
                catch { }

                connection.Close();
            }
        }

        return result;
    }

    public static int ExecuteNonQuery(string queryText)
    {
        return ExecuteNonQuery(queryText, false); 
    }

    public static DataSet ExecuteQuery(string queryText)
    {
        DataSet result = new DataSet();

        if (!string.IsNullOrEmpty(queryText))
        {
            using (var connection = new SqlConnection(GetConnectionString("MyExternalConnectionString")))
            {
                try
                {
                    using (SqlDataAdapter a = new SqlDataAdapter(queryText, connection))
                    {
                        a.Fill(result);
                    }
                }
                catch { }
            }
        }

        return result;
    }

    #endregion

    #region "Connector methods"

    public static bool ProcessTaskInternal(int eventUserID, TaskTypeEnum taskType)
    {
        bool result = false;

        if (eventUserID > 0)
        {
            DataSet eventUser = GetEventUser(eventUserID);

            if (eventUser != null && eventUser.Tables[0] != null && eventUser.Tables[0].Rows.Count > 0)
            {
                StringBuilder sb = new StringBuilder();
                sb.Append("<customdata>");

                foreach (DataColumn column in eventUser.Tables[0].Columns)
                {
                    sb.AppendFormat("<{0}>{1}</{0}>", column.ColumnName, eventUser.Tables[0].Rows[0][column.ColumnName].ToString().Trim());
                }

                sb.Append("</customdata>");

                MyWebServiceSoapClient mySoapClient = new MyWebServiceSoapClient();

                try
                {
                    mySoapClient.ProcessTask(sb.ToString(), taskType, ConfigurationManager.AppSettings["MyIntegrationConnectorUserName"], ConfigurationManager.AppSettings["MyIntegrationConnectorPassword"]);
                    mySoapClient.Close();

                    result = true;
                }
                catch
                {
                    return false;
                }

                mySoapClient.Close();
            }
        }

        return result;
    }

    public static HttpStatusCode PingExternalSytem()
    {
        string url = "http://localhost/70DEV/CMSPages/IntegrationNotify.aspx?connectorname=MyIntegrationConnector";

        HttpWebRequest request = WebRequest.Create(url) as HttpWebRequest;
        if (request != null)
        {
            HttpWebResponse response = request.GetResponse() as HttpWebResponse;
            if (response != null)
            {
                return response.StatusCode;
            }
        }
        return HttpStatusCode.InternalServerError;
    }

    #endregion
}