﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;

using ServiceReference;

public partial class EventUserEdit : System.Web.UI.Page
{
    #region "Variables"

    protected int mEventUserId = 0;

    #endregion

    #region "Properties"

    /// <summary>
    /// Event User ID.
    /// </summary>
    public int EventUserId
    {
        get
        {
            return mEventUserId;
        }
        set
        {
            mEventUserId = value;
        }
    }

    #endregion

    #region "Methods"

    protected void Page_Load(object sender, EventArgs e)
    {
        this.EventUserId = Convert.ToInt32(HttpContext.Current.Request.QueryString["eventUserId"]);
        int saved = Convert.ToInt32(HttpContext.Current.Request.QueryString["saved"]);
        string serverStatus = Convert.ToString(HttpContext.Current.Request.QueryString["serverStatus"]);

         if (!Page.IsPostBack)
         {
             InitializeControls();
             
             if (this.EventUserId > 0)
             {
                 LoadUserData();
             }
         }

         if (saved == 1)
         {
             lblInfo.Text = "Event user was registered ...";
         }

         if (saved == 2)
         {
             lblInfo.Text = "Event user was deleted ...";
             plEditor.Visible = false;
         }

         if (!string.IsNullOrEmpty(serverStatus))
         {
             lblInfo.Text += string.Format(" [EXTERNAL SERVER RESPONSE: '{0}']", serverStatus);
         }
    }

    public void InitializeControls()
    {
        if (drpEvent.Items.Count == 0)
        {
            string textField = "EventDisplayName";
            string valueField = "EventID";
            drpEvent.DataSource = MyEventHelper.GetAllEvents(textField + "," + valueField);
            drpEvent.DataTextField = textField;
            drpEvent.DataValueField = valueField;
            
            if (drpEvent.DataSource != null)
            {
                drpEvent.DataBind();
            }
        }

        // Disable option to change the event user 'event'
        if (this.EventUserId > 0)
        {
            drpEvent.Enabled = false;
        }
        else
        {
            btnDelete.Visible = false;
        }

    }

    public void LoadUserData()
    {
        if (EventUserId > 0)
        {
            DataSet eventUser = MyEventHelper.GetEventUser(EventUserId);

            if (eventUser != null && eventUser.Tables[0] != null && eventUser.Tables[0].Rows.Count > 0)
            {
                txtEmail.Text = eventUser.Tables[0].Rows[0]["EventUserEmail"].ToString().Trim();
                txtName.Text = eventUser.Tables[0].Rows[0]["EventUserName"].ToString().Trim();

                if (drpEvent.Items.Count > 0)
                {
                    drpEvent.SelectedValue = eventUser.Tables[0].Rows[0]["EventUserEventID"].ToString();
                }
            }
        }
    }

    protected void btnSubmit_Click(object sender, EventArgs e)
    {
        if (EventUserId > 0)
        {
            // Update
            if (MyEventHelper.UpdateEventUser(this.EventUserId, txtName.Text.Trim(), txtEmail.Text.Trim(), Convert.ToInt32(this.drpEvent.SelectedValue)))
            {
                // Contact Kentico with 'UPDATE' task
                MyEventHelper.ProcessTaskInternal(EventUserId, TaskTypeEnum.UpdateObject);

                lblInfo.Text = "Event user was updated ...";

                if (chckRealUpdate.Checked)
                {
                   lblInfo.Text += string.Format(" [EXTERNAL SERVER RESPONSE: '{0}']", MyEventHelper.PingExternalSytem());
                }
            }
        }
        else
        {
            // Insert
            EventUserId = MyEventHelper.CreateEventUser(txtName.Text.Trim(), txtEmail.Text.Trim(), Convert.ToInt32(drpEvent.SelectedValue));
            
            if (EventUserId > 0)
            {
                // Contact Kentico with 'CREATE' task
                MyEventHelper.ProcessTaskInternal(EventUserId, TaskTypeEnum.CreateObject);

                // Redirect user to the same page with 'new' id in query string
                Response.Redirect(Page.ResolveUrl("~/EventUserEdit.aspx?eventUserId=" + EventUserId + "&saved=1&serverStatus=" + MyEventHelper.PingExternalSytem()));
            }
        }
    }

    protected void btnDelete_Click(object sender, EventArgs e)
    {
        if (EventUserId > 0)
        {
            // Contact Kentico with 'DELETE' task
            MyEventHelper.ProcessTaskInternal(EventUserId, TaskTypeEnum.DeleteObject);
            
            // Delete
            if (MyEventHelper.DeleteEventUser(this.EventUserId))
            {
                // Redirect user to the same page with saved = 2 info in query string
                Response.Redirect(Page.ResolveUrl("~/EventUserEdit.aspx?saved=2&serverStatus=" + MyEventHelper.PingExternalSytem()));
            }
        }
    }

    #endregion
}