using System;
using System.Collections;
using System.Data;
using System.Web;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;

using CMS.GlobalHelper;
using CMS.IO;
using CMS.SettingsProvider;
using CMS.EventManager;
using CMS.DataEngine;

/// <summary>
/// MyIntegrationConnector methods.
/// </summary>
public static class MyIntegrationConnectorHelper
{
    # region "Constants"
    
    private const string EXTERNAL_CONNECTIONSTRING_NAME = "MyExternalConnectionString";
    
    #endregion

    #region "Helper methods"

    // ToDO
    public static bool ProcessObjectExternal(GeneralizedInfo att, TaskTypeEnum taskType, out string error)
    {
        bool pass = false;
        error = "";

        if (att != null)
        {
            switch (taskType)
            {
                case TaskTypeEnum.UpdateObject:
                    {
                        // Check if attendee exists in external system
                        if (AttendeeExists(att))
                        {
                            // Update attendee
                            pass = AttendeeUpdate(att);
                        }
                        else
                        {
                            error = string.Format("ERROR: User '{0}' does NOT exist in the external system.", att.ObjectDisplayName);
                        }
                    }
                        
                    break;

                case TaskTypeEnum.DeleteObject:
                    {
                        // Delete attendee
                        if (!AttendeeDelete(att))
                        {
                            error = string.Format("ERROR: User '{0}' can not be DELETED.", att.ObjectDisplayName);
                        }
                        else
                        {
                            pass = true;
                        }
                    }

                    break;

                case TaskTypeEnum.CreateObject:
                    {
                        // Check if attendee exists in external system
                        if (AttendeeExists(att))
                        {
                            error = string.Format("ERROR: User '{0}' already exists in the external system, can not be INSERTED.", att.ObjectDisplayName);
                        }
                        else
                        {
                            // Create attendee in external system
                            if (AttendeeCreate(att))
                            {
                                pass = true;
                            }
                            else
                            {
                                error = string.Format("ERROR: User '{0}' can not be CREATED in the external system.", att.ObjectDisplayName);
                            }
                        }
                    }

                    break;
            }

        }

        return pass;
    }
    
    // ToDO
    public static bool AttendeeExists(GeneralizedInfo att)
    {
        bool exists = false;

        if (Guid.Empty != att.ObjectGUID)
        {
            // Get query
            Query qi = QueryProvider.GetQuery("my.externalsystem.selectattendee", false);
            if (qi != null)
            {
                // Prepare the query data parameters
                QueryDataParameters parameters = new QueryDataParameters();
                parameters.Add("@EventUserGUID", att.ObjectGUID);

                // Prepare the query parameters
                QueryParameters query = new QueryParameters(
                    qi.QueryName,
                    qi.QueryText,
                    parameters,
                    qi.QueryType,
                    qi.RequiresTransaction,
                    "EventUserID", "", "", -1, ""
                    );

                if (!DataHelper.DataSourceIsEmpty(ExecuteQueryExternal(query)))
                {
                    exists = true;
                }
            }
        }
        
        return exists;
    }

    // ToDO
    public static bool AttendeeUpdate(GeneralizedInfo att)
    {
        bool pass = false;

        if (att != null)
        {
            // Get query
            Query qi = QueryProvider.GetQuery("my.externalsystem.updateattendee", false);
            if (qi != null)
            {
                // Prepare the query data parameters
                QueryDataParameters parameters = new QueryDataParameters();
                parameters.Add("@EventUserName", string.Format("{0} {1}", att.GetValue("AttendeeFirstName"), att.GetValue("AttendeeLastName")));
                parameters.Add("@EventUserEmail", att.GetValue("AttendeeEmail"));

                // Prepare the query parameters
                QueryParameters query = new QueryParameters(
                    qi.QueryName,
                    qi.QueryText,
                    parameters,
                    qi.QueryType,
                    qi.RequiresTransaction,
                    "", string.Format("EventUserGUID = '{0}'", att.ObjectGUID), "", -1, ""
                    );

                if (ExecuteNonQueryExternal(query) > 0)
                {
                    pass = true;
                }
            }
        }

        return pass;
    }

    // ToDO
    public static bool AttendeeDelete(GeneralizedInfo att)
    {
        bool pass = false;

        if (att != null)
        {
            // Get query
            Query qi = QueryProvider.GetQuery("my.externalsystem.deleteattendee", false);
            if (qi != null)
            {
                // Prepare the query data parameters
                QueryDataParameters parameters = new QueryDataParameters();
                parameters.Add("@EventUserGUID", att.ObjectGUID);

                // Prepare the query parameters
                QueryParameters query = new QueryParameters(
                    qi.QueryName,
                    qi.QueryText,
                    parameters,
                    qi.QueryType,
                    qi.RequiresTransaction,
                    "", "", "", -1, ""
                    );

                if (ExecuteNonQueryExternal(query) > 0)
                {
                    pass = true;
                }
            }
        }

        return pass;
    }

    // ToDO
    public static bool AttendeeCreate(GeneralizedInfo att)
    {
        bool pass = false;

        // Check if 'EventID' FK is NOT 0
        if (att != null && ValidationHelper.GetInteger(att.GetValue("AttendeeEventNodeID"), 0) > 0)
        {
            // Get query
            Query qi = QueryProvider.GetQuery("my.externalsystem.insertattendee", false);
            if (qi != null)
            {
                // Prepare the query data parameters
                QueryDataParameters parameters = new QueryDataParameters();
                parameters.Add("@EventUserName", string.Format("{0} {1}", att.GetValue("AttendeeFirstName"), att.GetValue("AttendeeLastName")));
                parameters.Add("@EventUserEventID", att.GetValue("AttendeeEventNodeID"));
                parameters.Add("@EventUserEmail", att.GetValue("AttendeeEmail"));
                parameters.Add("@EventUserGUID", att.ObjectGUID);

                // Prepare the query parameters
                QueryParameters query = new QueryParameters(
                    qi.QueryName,
                    qi.QueryText,
                    parameters,
                    qi.QueryType,
                    qi.RequiresTransaction,
                    "", "", "", -1, ""
                    );

                if (ExecuteNonQueryExternal(query) > 0)
                {
                    pass = true;
                }
            }
        }

        return pass;
    }

    // ToDO
    public static int GetEventID(Guid nodeGUID)
    {
        if (Guid.Empty != nodeGUID)
        {
            // Get query
            Query qi = QueryProvider.GetQuery("my.externalsystem.selectevent", false);
            if (qi != null)
            {
                // Prepare the query data parameters
                QueryDataParameters parameters = new QueryDataParameters();
                parameters.Add("@EventGUID", nodeGUID);
                
                // Prepare the query parameters
                QueryParameters query = new QueryParameters(
                    qi.QueryName, 
                    qi.QueryText, 
                    parameters, 
                    qi.QueryType, 
                    qi.RequiresTransaction, 
                    "EventID", "", "", -1, ""
                    );

                DataSet result = ExecuteQueryExternal(query);

                if (!DataHelper.DataSourceIsEmpty(result))
                {
                    return ValidationHelper.GetInteger(DataHelper.GetDataRowValue(result.Tables[0].Rows[0], "EventID"), 0);
                }
            }
        }

        return 0;
    }

    // ToDO
    public static Guid GetEventGUID(int eventID)
    {
        if (eventID > 0)
        {
            // Get query
            Query qi = QueryProvider.GetQuery("my.externalsystem.selecteventbyId", false);
            if (qi != null)
            {
                // Prepare the query data parameters
                QueryDataParameters parameters = new QueryDataParameters();
                parameters.Add("@EventID", eventID);

                // Prepare the query parameters
                QueryParameters query = new QueryParameters(
                    qi.QueryName,
                    qi.QueryText,
                    parameters,
                    qi.QueryType,
                    qi.RequiresTransaction,
                    "EventGUID", "", "", -1, ""
                    );

                DataSet result = ExecuteQueryExternal(query);

                if (!DataHelper.DataSourceIsEmpty(result))
                {
                    return ValidationHelper.GetGuid(DataHelper.GetDataRowValue(result.Tables[0].Rows[0], "EventGUID"), Guid.Empty);
                }
            }
        }

        return Guid.Empty;
    }
    
    // ToDO
    public static DataSet ExecuteQueryExternal(QueryParameters parameters)
    {
        DataSet result = null;

        using (new CMSConnectionScope(EXTERNAL_CONNECTIONSTRING_NAME, false))
        {
            try
            {
                // Run the query
              result = SqlHelperClass.ExecuteQuery(parameters);
            }
            catch { };
        }

        return result;
    }

    // ToDO
    public static int ExecuteNonQueryExternal(QueryParameters parameters)
    {
        int result = 0;

        try
        {
            using (new CMSConnectionScope(EXTERNAL_CONNECTIONSTRING_NAME, false))
            {
                GeneralConnection con = ConnectionHelper.GetConnection();

                // Resolve macros in query text
                parameters.ResolveMacros();
                
                result = con.ExecuteNonQuery(parameters.Text, parameters.Params, QueryTypeEnum.SQLQuery, false);
            }
        }
        catch { };

        return result;
    }

    // ToDO
    public static string WebServiceUserName
    {
        get
        {
            return SettingsKeyProvider.GetStringValue("WebServiceUserName");
        }
    }

    // ToDO
    public static string WebServicePassword
    {
        get
        {
            return SettingsKeyProvider.GetStringValue("WebServicePassword");
        }
    }

    #endregion
}